#!/bin/sh
# the next line restarts using tclsh\
exec tclsh "$0" "$@"

# Observation circumstance computer prototype.
# Port number:
set port 1234
# Identification:
set ident "circ.tcl v0.01"

#
#... Calculates the real altitude of Sun above horizon (no refraction accounted)
#
proc compute_hsun {} {
	# here we should put the formula hsun=f(UT, LONG, LAT).....................
	#..................................................
	# Instead, we model Sun altitude as a sine-wave
	set per 240; set amp 45; set zerol -20; set pi 3.14159265358979323
	return [expr $zerol+$amp*sin(fmod([clock seconds], $per)*2*$pi/$per)]
}

proc cmd_get pars {
	# global array of parameter values cmp_pvar(param)=value and comp.status:
	global cmp_pvar cmp_status ident
	foreach p $pars {
		switch $p {
			"ident"
				{ set cmp_pvar($p) $ident }
			"data"
				{ set cmp_pvar($p) "" }
			"hsun"
				{ set cmp_pvar($p) [compute_hsun] }
			default
				{ set cmp_status ERSYN; break }
		}
	}
}

proc cmd_init {} {
	global cmp_status
	# read CFG file?
	set cmp_status READY
}

proc cmd_go_local {} {
	global cmp_status
	# enable accepting local console commands
	set cmp_status LOCAL
}

proc cmd_park {} {
	global cmp_status cmp_pvar
	# possibly do nothing?
	# here we model long-term process:
#	set cmp_status BUSY
#	set cmp_pvar(wait) 10
#	after 10000 {}
		set cmp_status PARKED
#	{}
}

proc cmd_go_online {} {
	global cmp_status
	# disable local console commands
	set cmp_status READY
}

source compcmd.tcl

open_server $port
#while 1 { after 1000; puts "hsun=[format %-3.1f [compute_hsun]] deg" }
exit
